@@ -175,62 +175,67 @@ class Condition:
         elif self.field.complexExpression is not None:
             field_with_agg = self.field.complexExpression
 
-        if self.direction is None:
-            if negation is None:
-                where_condition = (
-                        field_with_agg + " " + operator + " " + str(formatted_value)
-                )
-            else:
-                where_condition = (
-                    field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
-                )
-        elif self.direction is not None:
-            if isinstance(self.direction, PeriodOperator):
-                direction = self.direction.name
-            else:
-                direction = self.direction
-            if negation is None:
-                if self.steps is not None and self.interval is not None:
+        if self.field.complexExpression is None:
+            if self.direction is None:
+                if negation is None:
                     where_condition = (
-                            field_with_agg + " " + operator + " " + self.interval + " " + direction + " " + self.steps
-                    )
-                elif self.steps is not None and self.interval is None:
-                    where_condition = (
-                            field_with_agg + " " + operator + " " + direction + " " + self.steps
-                    )
-                elif self.steps is None and self.interval is not None:
-                    where_condition = (
-                            field_with_agg + " " + operator + " " + self.interval + " " + direction
+                            field_with_agg + " " + operator + " " + str(formatted_value)
                     )
                 else:
                     where_condition = (
-                            field_with_agg + " " + operator + " " + direction
+                        field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
                     )
-            else:
-                if self.steps is not None and self.interval is not None:
+            elif self.direction is not None:
+                if isinstance(self.direction, PeriodOperator):
+                    direction = self.direction.name
+                else:
+                    direction = self.direction
+                if negation is None:
+                    if self.steps is not None and self.interval is not None:
+                        where_condition = (
+                                field_with_agg + " " + operator + " " + self.interval + " " + direction + " " + self.steps
+                        )
+                    elif self.steps is not None and self.interval is None:
+                        where_condition = (
+                                field_with_agg + " " + operator + " " + direction + " " + self.steps
+                        )
+                    elif self.steps is None and self.interval is not None:
+                        where_condition = (
+                                field_with_agg + " " + operator + " " + self.interval + " " + direction
+                        )
+                    else:
+                        where_condition = (
+                                field_with_agg + " " + operator + " " + direction
+                        )
+                else:
+                    if self.steps is not None and self.interval is not None:
+                        where_condition = (
+                                field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction + " " + self.steps
+                        )
+                    elif self.steps is not None and self.interval is None:
+                        where_condition = (
+                                field_with_agg + " " + negation + " " + operator + " " + direction + " " + self.steps
+                        )
+                    elif self.steps is None and self.interval is not None:
+                        where_condition = (
+                                field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction
+                        )
+                    else:
+                        where_condition = (
+                                field_with_agg + " " + negation + " " + operator + " " + direction
+                        )
+            elif operator is not None:
+                if negation is None:
                     where_condition = (
-                            field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction + " " + self.steps
-                    )
-                elif self.steps is not None and self.interval is None:
-                    where_condition = (
-                            field_with_agg + " " + negation + " " + operator + " " + direction + " " + self.steps
-                    )
-                elif self.steps is None and self.interval is not None:
-                    where_condition = (
-                            field_with_agg + " " + negation + " " + operator + " " + self.interval + " " + direction
+                            field_with_agg + " " + operator
                     )
                 else:
                     where_condition = (
-                            field_with_agg + " " + negation + " " + operator + " " + direction
+                        field_with_agg + " " + negation + " " + operator
                     )
-        elif operator is not None:
-            if negation is None:
-                where_condition = (
-                        field_with_agg + " " + operator
-                )
             else:
                 where_condition = (
-                    field_with_agg + " " + negation + " " + operator
+                    field_with_agg
                 )
         else:
             where_condition = (
@@ -310,6 +315,11 @@ class Join:
 class GroupBy:
     field: Field
 
+@dataclass
+class UnmatchedField:
+    name: str
+    type: str
+    filter: bool
 
 @dataclass
 class Query:
@@ -323,6 +333,7 @@ class Query:
     orderBy: Optional[List[Sorting]] = None
     limit: Optional[Union[int, str]] = None
     offset: Optional[Union[int, str]] = None
+    unmatched: Optional[List[UnmatchedField]] = None
 
     def to_sql(self, dataset: str = None):
         sql = "SELECT {} FROM {}"
